# flake8: noqa

"""
    Tags API

    Tags are case-sensitive key-value pairs that simplify resource management. The Tag Manager API allows you to create and manage such tags to later assign them to related resources in your Bare Metal Cloud (through the respective resource apis) in order to group and categorize them.<br> <br> <span class='pnap-api-knowledge-base-link'> Knowledge base articles to help you can be found <a href='https://phoenixnap.com/kb/bmc-server-management-via-api#server-tag-manager-api' target='_blank'>here</a> </span><br> <br> <b>All URLs are relative to (https://api.phoenixnap.com/tag-manager/v1/)</b>   # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: support@phoenixnap.com
    Generated by: https://openapi-generator.tech
"""


# import ApiClient
from pnap_tag_api.api_client import ApiClient

# import Configuration
from pnap_tag_api.configuration import Configuration

# import exceptions
from pnap_tag_api.exceptions import OpenApiException
from pnap_tag_api.exceptions import ApiAttributeError
from pnap_tag_api.exceptions import ApiTypeError
from pnap_tag_api.exceptions import ApiValueError
from pnap_tag_api.exceptions import ApiKeyError
from pnap_tag_api.exceptions import ApiException
from pnap_tag_api.version import VERSION
__version__ = VERSION
